@@ -10,7 +10,7 @@ use English;
 use Exporter 'import';
 use List::Util 'any', 'all', 'pairs';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 our @EXPORT_OK = qw(validate_options);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -181,9 +181,8 @@ sub _word_list {
 =head3 B<parse_file_metadata> I<(enum, default: yaml)>
 
 This option controls whether the parser accepts optional metadata at the
-beginning of the file. Currently, it does nothing with these metadata, even when
-they are accepted. In the future they might be used to build complete HTML file
-instead of just fragment.
+beginning of the file. The module currently does nothing with the metadata
+itself but you can configure a hook to receive the YAML content.
 
 The possible values are:
 
@@ -435,6 +434,19 @@ _make_option(
 
 =pod
 
+=head3 B<yaml_file_metadata_allows_empty_lines> I<(boolean, default: false)>
+
+YAML document at the beginning of a Markdown file can contain empty lines. Note
+that with this some reasonable Markdown documents can be interpreted as YAML so
+you should set this value to true only if you expect to use YAML metadata with
+your files.
+
+=cut
+
+_make_option(yaml_file_metadata_allows_empty_lines => 0, _boolean);
+
+=pod
+
 =head2 Options controlling the rendering of top-level blocks
 
 =head3 B<code_blocks_info> I<(enum, default: language)>
